@@ -7,12 +7,9 @@ from typing import ClassVar
 from typing import Generic
 from typing import Iterable
 from typing import Iterator
-from typing import Sequence
 from typing import TypeVar
-from typing import cast
 
 from typing_extensions import Protocol
-from typing_extensions import get_args
 from typing_extensions import runtime_checkable
 
 from ._utils.misc import BoundType
@@ -21,12 +18,10 @@ from ._utils.misc import UnresolvedClassAttribute
 from ._utils.misc import fully_qualified_name
 from ._utils.misc import is_not_known_mutable_type
 from ._utils.misc import is_subtype
-from ._utils.misc import is_union
 from ._utils.misc import resolve_class_attr
+from .bounds import get_bound_parser
+from .errors import BoundError
 from .predicates import Predicate
-from .predicates.boolean import all_of
-from .predicates.generic import of_complex_type
-from .predicates.generic import of_type
 from .schema import SchemaField
 
 
@@ -53,43 +48,9 @@ class PhantomMeta(abc.ABCMeta):
         return cls.parse(instance)  # type: ignore[attr-defined]
 
 
-class BoundError(TypeError):
-    ...
-
-
 T = TypeVar("T", covariant=True)
 
 
-def display_bound(bound: Any) -> str:
-    if isinstance(bound, Iterable):
-        return f"Intersection[{', '.join(display_bound(part) for part in bound)}]"
-    if is_union(bound):
-        return (
-            f"typing.Union["
-            f"{', '.join(display_bound(part) for part in get_args(bound))}"
-            f"]"
-        )
-    return str(getattr(bound, "__name__", bound))
-
-
-def get_bound_parser(bound: Any) -> Callable[[object], T]:
-    within_bound = (
-        # Interpret sequence as intersection
-        all_of(of_type(t) for t in bound)
-        if isinstance(bound, Sequence)
-        else of_complex_type(bound)
-    )
-
-    def parser(instance: object) -> T:
-        if not within_bound(instance):
-            raise BoundError(
-                f"Value is not within bound of {display_bound(bound)!r}: {instance!r}"
-            )
-        return cast(T, instance)
-
-    return parser
-
-
 Derived = TypeVar("Derived", bound="PhantomBase")
 
 
